All Classes and Interfaces

Class
Description
You do not have sufficient access to perform this action.
 
An AWS Arn.
An object that represents the custom domain name association.
 
 
An array of key-value pairs to set for advanced control over Amazon Redshift Serverless.
 
The submitted action has conflicts.
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
The parameters that you can use to configure a scheduled action to create a snapshot.
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
This exception is thrown when the request was successful, but dry run was enabled so no action was taken.
 
The VPC endpoint object.
 
Information about an Amazon Redshift Serverless VPC endpoint.
 
Link between an endpoint property and the AwsEndpointAttribute it represents.
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
GetTrackRequest Marshaller
 
 
 
 
 
 
 
 
 
 
Identifiers for variables declared within the rule engine, e.g.
There is an insufficient capacity to perform the action.
 
The request processing has failed because of an unknown error, exception or failure.
 
The provided pagination token is invalid.
 
There are no subnets in your VPC with associated IPv6 CIDR blocks.
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
A collection of Amazon Redshift compute resources managed by Glue.
 
 
A collection of database objects and users.
 
 
Contains information about a network interface in an Amazon Redshift Serverless managed VPC endpoint.
 
 
 
 
 
 
 
 
 
An object that represents the price performance target settings for the workgroup.
 
 
 
 
 
 
 
The automatically created recovery point of a namespace.
 
Service client for accessing Redshift Serverless asynchronously.
A builder for creating an instance of RedshiftServerlessAsyncClient.
 
The parameters object used to resolve the auth schemes for the RedshiftServerless service.
An auth scheme provider for RedshiftServerless service.
This includes configuration specific to Redshift Serverless that is supported by both RedshiftServerlessClientBuilder and RedshiftServerlessAsyncClientBuilder.
Service client for accessing Redshift Serverless.
A builder for creating an instance of RedshiftServerlessClient.
 
The parameters object used to resolve an endpoint for the RedshiftServerless service.
 
An endpoint provider for RedshiftServerless.
 
 
 
 
 
 
 
 
 
 
 
 
Class to expose the service client settings to the user.
 
 
 
Represents an Amazon Redshift Serverless reservation, which gives you the option to commit to a specified number of Redshift Processing Units (RPUs) for a year at a discount from Serverless on-demand (OD) rates.
 
The class of offering for the reservation.
 
The resource could not be found.
 
The resource policy object.
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
Represents a URL to be used internally for endpoint resolution.
The schedule of when Amazon Redshift Serverless should run the scheduled action.
 
 
Contains names of objects associated with a scheduled action.
 
The returned scheduled action object.
 
Defines a track that determines which Amazon Redshift version to apply after a new version is released.
 
The service limit was exceeded.
 
 
A snapshot object that contains databases.
 
The object that you configure to copy snapshots from one namespace to a namespace in another Amazon Web Services Region.
 
 
 
Contains information about a table restore request.
 
A map of key-value pairs.
 
 
 
 
 
A JSON format string of the Amazon Redshift Serverless API operation with input parameters.
 
 
The request was denied due to request throttling.
 
The request exceeded the number of tags allowed for a resource.
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
A track that you can switch the current track to.
 
 
 
 
 
 
 
 
 
The usage limit object.
 
 
 
 
 
The input failed to satisfy the constraints specified by an Amazon Web Services service.
 
Base class for the types of values computable by the RuleEngine.
An array value.
A boolean value.
 
 
An integer value.
 
A record (map) value.
A string value.
The connection endpoint for connecting to Amazon Redshift Serverless through the proxy.
 
Describes the members of a VPC security group.
 
The collection of computing resources from which an endpoint is created.