All Classes and Interfaces
Class
Description
You do not have sufficient access to perform this action.
An AWS Arn.
An object that represents the custom domain name association.
An array of key-value pairs to set for advanced control over Amazon Redshift Serverless.
The submitted action has conflicts.
ConvertRecoveryPointToSnapshotRequest MarshallerCreateCustomDomainAssociationRequest MarshallerCreateEndpointAccessRequest MarshallerCreateNamespaceRequest MarshallerCreateReservationRequest MarshallerCreateScheduledActionRequest MarshallerCreateSnapshotCopyConfigurationRequest MarshallerCreateSnapshotRequest Marshaller
The parameters that you can use to configure a scheduled
action to create a snapshot.
CreateUsageLimitRequest MarshallerCreateWorkgroupRequest MarshallerDeleteCustomDomainAssociationRequest MarshallerDeleteEndpointAccessRequest MarshallerDeleteNamespaceRequest MarshallerDeleteResourcePolicyRequest MarshallerDeleteScheduledActionRequest MarshallerDeleteSnapshotCopyConfigurationRequest MarshallerDeleteSnapshotRequest MarshallerDeleteUsageLimitRequest MarshallerDeleteWorkgroupRequest Marshaller
This exception is thrown when the request was successful, but dry run was enabled so no action was taken.
The VPC endpoint object.
Information about an Amazon Redshift Serverless VPC endpoint.
Link between an endpoint property and the
AwsEndpointAttribute it represents.GetCredentialsRequest MarshallerGetCustomDomainAssociationRequest MarshallerGetEndpointAccessRequest MarshallerGetIdentityCenterAuthTokenRequest MarshallerGetNamespaceRequest MarshallerGetRecoveryPointRequest MarshallerGetReservationOfferingRequest MarshallerGetReservationRequest MarshallerGetResourcePolicyRequest MarshallerGetScheduledActionRequest MarshallerGetSnapshotRequest MarshallerGetTableRestoreStatusRequest MarshallerGetTrackRequest MarshallerGetUsageLimitRequest MarshallerGetWorkgroupRequest MarshallerIdentifiers for variables declared within the rule engine, e.g.
There is an insufficient capacity to perform the action.
The request processing has failed because of an unknown error, exception or failure.
The provided pagination token is invalid.
There are no subnets in your VPC with associated IPv6 CIDR blocks.
Represents the output for the
RedshiftServerlessClient.listCustomDomainAssociationsPaginator(software.amazon.awssdk.services.redshiftserverless.model.ListCustomDomainAssociationsRequest)
operation which is a paginated operation.
Represents the output for the
RedshiftServerlessAsyncClient.listCustomDomainAssociationsPaginator(software.amazon.awssdk.services.redshiftserverless.model.ListCustomDomainAssociationsRequest)
operation which is a paginated operation.ListCustomDomainAssociationsRequest Marshaller
Represents the output for the
RedshiftServerlessClient.listEndpointAccessPaginator(software.amazon.awssdk.services.redshiftserverless.model.ListEndpointAccessRequest)
operation which is a paginated operation.
Represents the output for the
RedshiftServerlessAsyncClient.listEndpointAccessPaginator(software.amazon.awssdk.services.redshiftserverless.model.ListEndpointAccessRequest)
operation which is a paginated operation.ListEndpointAccessRequest Marshaller
Represents the output for the
RedshiftServerlessClient.listManagedWorkgroupsPaginator(software.amazon.awssdk.services.redshiftserverless.model.ListManagedWorkgroupsRequest)
operation which is a paginated operation.
Represents the output for the
RedshiftServerlessAsyncClient.listManagedWorkgroupsPaginator(software.amazon.awssdk.services.redshiftserverless.model.ListManagedWorkgroupsRequest)
operation which is a paginated operation.ListManagedWorkgroupsRequest Marshaller
Represents the output for the
RedshiftServerlessClient.listNamespacesPaginator(software.amazon.awssdk.services.redshiftserverless.model.ListNamespacesRequest)
operation which is a paginated operation.
Represents the output for the
RedshiftServerlessAsyncClient.listNamespacesPaginator(software.amazon.awssdk.services.redshiftserverless.model.ListNamespacesRequest)
operation which is a paginated operation.ListNamespacesRequest Marshaller
Represents the output for the
RedshiftServerlessClient.listRecoveryPointsPaginator(software.amazon.awssdk.services.redshiftserverless.model.ListRecoveryPointsRequest)
operation which is a paginated operation.
Represents the output for the
RedshiftServerlessAsyncClient.listRecoveryPointsPaginator(software.amazon.awssdk.services.redshiftserverless.model.ListRecoveryPointsRequest)
operation which is a paginated operation.ListRecoveryPointsRequest Marshaller
Represents the output for the
RedshiftServerlessClient.listReservationOfferingsPaginator(software.amazon.awssdk.services.redshiftserverless.model.ListReservationOfferingsRequest)
operation which is a paginated operation.
Represents the output for the
RedshiftServerlessAsyncClient.listReservationOfferingsPaginator(software.amazon.awssdk.services.redshiftserverless.model.ListReservationOfferingsRequest)
operation which is a paginated operation.ListReservationOfferingsRequest Marshaller
Represents the output for the
RedshiftServerlessClient.listReservationsPaginator(software.amazon.awssdk.services.redshiftserverless.model.ListReservationsRequest)
operation which is a paginated operation.
Represents the output for the
RedshiftServerlessAsyncClient.listReservationsPaginator(software.amazon.awssdk.services.redshiftserverless.model.ListReservationsRequest)
operation which is a paginated operation.ListReservationsRequest Marshaller
Represents the output for the
RedshiftServerlessClient.listScheduledActionsPaginator(software.amazon.awssdk.services.redshiftserverless.model.ListScheduledActionsRequest)
operation which is a paginated operation.
Represents the output for the
RedshiftServerlessAsyncClient.listScheduledActionsPaginator(software.amazon.awssdk.services.redshiftserverless.model.ListScheduledActionsRequest)
operation which is a paginated operation.ListScheduledActionsRequest Marshaller
Represents the output for the
RedshiftServerlessClient.listSnapshotCopyConfigurationsPaginator(software.amazon.awssdk.services.redshiftserverless.model.ListSnapshotCopyConfigurationsRequest)
operation which is a paginated operation.
Represents the output for the
RedshiftServerlessAsyncClient.listSnapshotCopyConfigurationsPaginator(software.amazon.awssdk.services.redshiftserverless.model.ListSnapshotCopyConfigurationsRequest)
operation which is a paginated operation.ListSnapshotCopyConfigurationsRequest Marshaller
Represents the output for the
RedshiftServerlessClient.listSnapshotsPaginator(software.amazon.awssdk.services.redshiftserverless.model.ListSnapshotsRequest)
operation which is a paginated operation.
Represents the output for the
RedshiftServerlessAsyncClient.listSnapshotsPaginator(software.amazon.awssdk.services.redshiftserverless.model.ListSnapshotsRequest)
operation which is a paginated operation.ListSnapshotsRequest Marshaller
Represents the output for the
RedshiftServerlessClient.listTableRestoreStatusPaginator(software.amazon.awssdk.services.redshiftserverless.model.ListTableRestoreStatusRequest)
operation which is a paginated operation.
Represents the output for the
RedshiftServerlessAsyncClient.listTableRestoreStatusPaginator(software.amazon.awssdk.services.redshiftserverless.model.ListTableRestoreStatusRequest)
operation which is a paginated operation.ListTableRestoreStatusRequest MarshallerListTagsForResourceRequest Marshaller
Represents the output for the
RedshiftServerlessClient.listTracksPaginator(software.amazon.awssdk.services.redshiftserverless.model.ListTracksRequest)
operation which is a paginated operation.
Represents the output for the
RedshiftServerlessAsyncClient.listTracksPaginator(software.amazon.awssdk.services.redshiftserverless.model.ListTracksRequest)
operation which is a paginated operation.ListTracksRequest Marshaller
Represents the output for the
RedshiftServerlessClient.listUsageLimitsPaginator(software.amazon.awssdk.services.redshiftserverless.model.ListUsageLimitsRequest)
operation which is a paginated operation.
Represents the output for the
RedshiftServerlessAsyncClient.listUsageLimitsPaginator(software.amazon.awssdk.services.redshiftserverless.model.ListUsageLimitsRequest)
operation which is a paginated operation.ListUsageLimitsRequest Marshaller
Represents the output for the
RedshiftServerlessClient.listWorkgroupsPaginator(software.amazon.awssdk.services.redshiftserverless.model.ListWorkgroupsRequest)
operation which is a paginated operation.
Represents the output for the
RedshiftServerlessAsyncClient.listWorkgroupsPaginator(software.amazon.awssdk.services.redshiftserverless.model.ListWorkgroupsRequest)
operation which is a paginated operation.ListWorkgroupsRequest Marshaller
A collection of Amazon Redshift compute resources managed by Glue.
A collection of database objects and users.
Contains information about a network interface in an Amazon Redshift Serverless managed VPC endpoint.
An object that represents the price performance target settings for the workgroup.
PutResourcePolicyRequest Marshaller
The automatically created recovery point of a namespace.
Service client for accessing Redshift Serverless asynchronously.
A builder for creating an instance of
RedshiftServerlessAsyncClient.The parameters object used to resolve the auth schemes for the RedshiftServerless service.
A builder for a
RedshiftServerlessAuthSchemeParams.An auth scheme provider for RedshiftServerless service.
This includes configuration specific to Redshift Serverless that is supported by both
RedshiftServerlessClientBuilder and RedshiftServerlessAsyncClientBuilder.Service client for accessing Redshift Serverless.
A builder for creating an instance of
RedshiftServerlessClient.The parameters object used to resolve an endpoint for the RedshiftServerless service.
An endpoint provider for RedshiftServerless.
Class to expose the service client settings to the user.
A builder for creating a
RedshiftServerlessServiceClientConfiguration
Represents an Amazon Redshift Serverless reservation, which gives you the option to commit to a specified number of
Redshift Processing Units (RPUs) for a year at a discount from Serverless on-demand (OD) rates.
The class of offering for the reservation.
The resource could not be found.
The resource policy object.
RestoreFromRecoveryPointRequest MarshallerRestoreFromSnapshotRequest MarshallerRestoreTableFromRecoveryPointRequest MarshallerRestoreTableFromSnapshotRequest MarshallerRepresents a URL to be used internally for endpoint resolution.
The schedule of when Amazon Redshift Serverless should run the scheduled action.
Contains names of objects associated with a scheduled action.
The returned scheduled action object.
Defines a track that determines which Amazon Redshift version to apply after a new version is released.
The service limit was exceeded.
A snapshot object that contains databases.
The object that you configure to copy snapshots from one namespace to a namespace in another Amazon Web Services
Region.
Contains information about a table restore request.
A map of key-value pairs.
TagResourceRequest Marshaller
A JSON format string of the Amazon Redshift Serverless API operation with input parameters.
The request was denied due to request throttling.
The request exceeded the number of tags allowed for a resource.
UntagResourceRequest MarshallerUpdateCustomDomainAssociationRequest MarshallerUpdateEndpointAccessRequest MarshallerUpdateLakehouseConfigurationRequest MarshallerUpdateNamespaceRequest MarshallerUpdateScheduledActionRequest MarshallerUpdateSnapshotCopyConfigurationRequest MarshallerUpdateSnapshotRequest Marshaller
A track that you can switch the current track to.
UpdateUsageLimitRequest MarshallerUpdateWorkgroupRequest Marshaller
The usage limit object.
The input failed to satisfy the constraints specified by an Amazon Web Services service.
Base class for the types of values computable by the
RuleEngine.An array value.
A boolean value.
An integer value.
A record (map) value.
A string value.
The connection endpoint for connecting to Amazon Redshift Serverless through the proxy.
Describes the members of a VPC security group.
The collection of computing resources from which an endpoint is created.